A data.frame with one row per each unique value of x.
These values of x are assigned to the row.names of the data.frame.
The data.frame also has rows for:
Valid TotalThe total number of non-missing cases (i.e., sum(!is.na(x)))
MissingThe total number of missing/NA cases (i.e., sum(is.na(x)))
TotalThe total number of cases (i.e., length(x))
The data.frame has the following columns:
freqThe number of cases with this value
percentThe percentage of all cases that this value represents
valid_percentThe percentage of all valid (i.e., not missing) cases that this value represents
cum_percentThe cumulative percentage of valid cases